** use CB_CMPS_replication.dta

set more off 

******
*TABLE 1 
******
*** MODEL 1 - gov't prevalence (bivariate)
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev if sample==1, nohr compete(outcome = 1,2,4) vce(robust)

*** MODEL 2 - rebel prevalence (bivariate)
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg rebprev if sample==1, nohr compete(outcome = 1,2,4) vce(robust)

*** MODEL 3 - equal abuse (bivariate)
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg eqabuse1 if sample==1, nohr compete(outcome = 1,2,4) vce(robust)

*** MODEL 4 - prevalence (multivariate)
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)

*** MODEL 5 - equal abuse (multivariate)
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)


******
*FIGURE 1 
******
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)
stcurve, cif at0(govprev=0) at1(govprev=1) at2(govprev=2) at3(govprev=3) title("Cumulative Incidence Function")  xtitle("Years of Conflict") ytitle("Likelihood of Negotiated Outcome") lpattern(solid dash shortdash dash_dot) clcolor(black black black black) legend(order(1 "Gov't Prevalence=0" 2 "Gov't Prevalence=1" 3 "Gov't Prevalence=2" 4 "Gov't Prevalence=3")) graphregion(color(white)) 


******
*FIGURE 2 
******
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)
stcurve, cif at0(eqabuse1=0) at1(eqabuse1=1) title("Cumulative Incidence Function")  xtitle("Years of Conflict") ytitle("Likelihood of Negotiated Outcome") lpattern(solid dash) clcolor(black black) legend(order(1 "Equal Abuse=0" 2 "Equal Abuse=1")) graphregion(color(white)) 



***********************************************



******
*TABLE A1 IN APPENDIX - summary statistics
******
sutex outcome govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, minmax


******** 
*TABLE A2 IN APPENDIX - full CR specifications for all outcomes of Model 4
********
* MODEL 3: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 4: REBELS WIN 
stset yearnumber_1989, id(dyadep) failure( outcome =2)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 5: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 6: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,3) vce(robust)


*******
*TABLE A3 IN APPENDIX - full CR specifications for all outcomes of Model 5
*******
* MODEL 7: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 8: REBELS WIN 
stset yearnumber_1989, id(dyadep) failure( outcome =2)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 9: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 10: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev rebprev eqabuse1 weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,3) vce(robust)


*******
*TABLE A4 IN APPENDIX - changes in levels of abuse
*******
* MODEL 11: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev govescal govdeescal rebprev rebescal rebdeescal weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 12: REBELS WIN (not concave)
stset yearnumber_1989, id(dyadep) failure( outcome =2)
* stcrreg govprev govescal govdeescal rebprev rebescal rebdeescal weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 13: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev govescal govdeescal rebprev rebescal rebdeescal weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 14: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev govescal govdeescal rebprev rebescal rebdeescal weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,3) vce(robust)


*******
*TABLE A5 IN APPENDIX - rebels w/ & w/o external support (those concerned or not w/winning hearts & minds)
*******
* MODEL 15: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev rebprev rsvxext weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 16: REBELS WIN 
stset yearnumber_1989, id(dyadep) failure( outcome =2)
stcrreg govprev rebprev rsvxext weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 17: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev rsvxext weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 18: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev rebprev rsvxext weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp, nohr compete(outcome = 1,2,3) vce(robust)

*******
*TABLE A6 IN APPENDIX - splitting sample using women's political rights (lo vs hi)
*******
* MODEL 19: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==0, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 20: REBELS WIN 
stset yearnumber_1989, id(dyadep) failure( outcome =2)
*stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==0, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 21: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==0, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 22: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==0, nohr compete(outcome = 1,2,3) vce(robust)

* MODEL 23: GOVERNMENT WINS
stset yearnumber_1989, id(dyadep) failure( outcome =1)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==1, nohr compete(outcome = 2,3,4) vce(robust)

* MODEL 24: REBELS WIN 
stset yearnumber_1989, id(dyadep) failure( outcome =2)
*stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==1, nohr compete(outcome = 1,3,4) vce(robust)

* MODEL 25: NEGOTIATION
stset yearnumber_1989, id(dyadep) failure( outcome =3)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==1, nohr compete(outcome = 1,2,4) vce(robust)

* MODEL 26: LOW ACTIVITY
stset yearnumber_1989, id(dyadep) failure( outcome =4)
stcrreg govprev rebprev weakreb govsup rebsup lnbd lngosv lnrosv lpkok llnmilper polity2 madlnpop madlgdp if poleq==1, nohr compete(outcome = 1,2,3) vce(robust)
